==> mono_1.2.4.orig.tar.gz: mono-1.2.4/mcs/class/System.Core/System.Linq.Expressions/MemberAssignment.cs <==
﻿// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
//
// Authors:
//        Antonello Provenzano  <antonello@deveel.com>
//

using System.Reflection;
using System.Text;

namespace System.Linq.Expressions
{
    public sealed class MemberAssignment : MemberBinding
    {
        #region .ctor
        internal MemberAssignment(MemberInfo member, Expression expression)
            : base(MemberBindingType.Assignment, member)
        {
            this.expression = expression;
        }
        #endregion

        #region Fields
        private Expression expression;
        #endregion

        #region Properties
        public Expression Expression
        {
            get { return expression; }
        }
        #endregion

        #region Internal Methods
        internal override void BuildString(StringBuilder builder)
        {
            string memberName = base.Member.Name;
            builder.Append(memberName);
            builder.Append("=");
            expression.BuildString(builder);
        }
        #endregion
    }
}

==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/System.Core/System.Linq.Expressions/MemberAssignment.cs <==
﻿// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
//
// Authors:
//        Antonello Provenzano  <antonello@deveel.com>
//

using System.Reflection;
using System.Text;

namespace System.Linq.Expressions
{
    public sealed class MemberAssignment : MemberBinding
    {
        #region .ctor
        internal MemberAssignment (MemberInfo member, Expression expression)
            : base (MemberBindingType.Assignment, member)
        {
            this.expression = expression;
        }
        #endregion

        #region Fields
        private Expression expression;
        #endregion

        #region Properties
        public Expression Expression {
            get { return expression; }
        }
        #endregion

        #region Internal Methods
        internal override void BuildString (StringBuilder builder)
        {
            builder.Append (Member.Name).Append (" = ");
            expression.BuildString (builder);
        }
        #endregion
    }
}
